==> xray_audit-1.2.0.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskNodePlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_node",
 *   label = @Translation("Node reports"),
 *   description = @Translation("Reports on the Node content entity of this site."),
 *   group = "queries_data",
 *   sort = 2,
 *   operations = {
 *      "node_by_types" = {
 *          "label" = "Number of node types",
 *          "description" = "Node types, number of published and unpublished, and totals of nodes in the default language."
 *       },
 *       "node_types_per_language_language" = {
 *          "label" = "Number of node types per language",
 *          "description" = "List of node types and their respective counts per language."
 *       }
 *    },
 *   dependencies = {"node"}
 * )
 */
class XrayAuditQueryTaskNodePlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'node_by_types':
        return $this->nodeByTypes();

      case 'node_types_per_language_language':
        return $this->nodeTypesPerLanguage();
    }
    return [];
  }

  /**
   * Get data for operation "node_by_types".
   *
   * @return array
   *   Render array.
   */
  protected function nodeByTypes() {

    $alias_count = 'count';
    $headerTable = [
      $this->t('Label'),
      $this->t('Id'),
      $this->t('Langcode'),
      $this->t('Total'),
      $this->t('Published'),
      $this->t('Unpublished'),
    ];
    $resultTable = [];

    // Get label of content types.
    $label_content_types = [];
    $types = $this->entityTypeManager->getStorage("node_type")->loadMultiple();
    foreach ($types as $key => $type) {
      $label_content_types[$key] = $type->label();
    }

    $bundles_counted = [];

    $language_by_default = $this->languageManager->getDefaultLanguage()->getId();
    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();

    $publish_bundle = $query->accessCheck(FALSE)
      ->condition('status', '1')
      ->groupBy('type')
      ->aggregate('nid', 'count', $language_by_default, $alias_count)
      ->execute();
    foreach ($publish_bundle as $bundle) {
      $bundles_counted[$bundle['type']]['publish'] = $bundle['count'];
    }

    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $unpublish_bundle = $query->accessCheck(FALSE)
      ->condition('status', '1', '!=')
      ->groupBy('type')
      ->aggregate('nid', 'count', $language_by_default, $alias_count)
      ->execute();
    foreach ($unpublish_bundle as $bundle) {
      $bundles_counted[$bundle['type']]['unpublish'] = $bundle['count'];
    }

    $total = 0;
    $total_publish = 0;
    $total_no_publish = 0;
    foreach ($label_content_types as $bundle => $conent_type_label) {
      $publish = $bundles_counted[$bundle]['publish'] ?? 0;
      $unpublish = $bundles_counted[$bundle]['unpublish'] ?? 0;
      $resultTable[$bundle] = [
        'label' => $conent_type_label,
        'id' => $bundle,
        'langcode' => $language_by_default,
        'total' => $publish + $unpublish,
        'publish' => $publish,
        'no_publish' => $unpublish,
      ];
      $total += $publish + $unpublish;
      $total_publish += $publish;
      $total_no_publish += $unpublish;
    }
    $resultTable['total']['label'] = $this->t('TOTAL');
    $resultTable['total']['id'] = '---';
    $resultTable['total']['langcode'] = '---';
    $resultTable['total']['total'] = $total;
    $resultTable['total']['publish'] = $total_publish;
    $resultTable['total']['no-publish'] = $total_no_publish;

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Get data for operation "node_by_types_language".
   *
   * @return array
   *   Render array.
   */
  protected function nodeTypesPerLanguage() {

    $alias = 'count';

    $headerTable = [
      $this->t('label'),
      $this->t('id'),
      $this->t('langcode'),
      $this->t('total'),
    ];
    $resultTable = [];

    // Get label of content types.
    $label = [];
    $types = $this->entityTypeManager->getStorage("node_type")->loadMultiple();
    foreach ($types as $key => $type) {
      $label[$key] = $type->label();
    }

    $query = $this->entityTypeManager->getStorage("node")->getAggregateQuery();
    $result = $query->accessCheck(FALSE)
      ->aggregate('nid', 'COUNT', NULL, $alias)
      ->groupBy('langcode')
      ->groupBy('type')
      ->execute();

    foreach ($result as $row) {
      $resultTable[] = [
        'label' => $label[$row['type']],
        'id' => $row['type'],
        'langcode' => $row['langcode'],
        'total' => $row['count'] ?? 0,
      ];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

}

==> xray_audit-1.3.2.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskNodePlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_node",
 *   label = @Translation("Node reports"),
 *   description = @Translation("Reports on the Node content entity of this site."),
 *   group = "queries_data",
 *   sort = 2,
 *   operations = {
 *      "node_by_types" = {
 *          "label" = "Number of node types",
 *          "description" = "Node types, number of published and unpublished,
 *            and totals of nodes in the default language."
 *       },
 *       "node_types_per_language_language" = {
 *          "label" = "Number of node types per language",
 *          "description" = "List of node types and their respective counts per
 *            language."
 *       }
 *    },
 *   dependencies = {"node"}
 * )
 */
class XrayAuditQueryTaskNodePlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'node_by_types':
        return $this->nodeByTypes();

      case 'node_types_per_language_language':
        return $this->nodeTypesPerLanguage();
    }
    return [];
  }

  /**
   * Get data for operation "node_by_types".
   *
   * @return array
   *   Render array.
   */
  protected function nodeByTypes() {

    $alias_count = 'count';
    $headerTable = [
      $this->t('Label'),
      $this->t('Id'),
      $this->t('Langcode'),
      $this->t('Total'),
      $this->t('Published'),
      $this->t('Unpublished'),
    ];
    $resultTable = [];

    // Get label of content types.
    $label_content_types = [];
    $types = $this->entityTypeManager->getStorage("node_type")->loadMultiple();
    foreach ($types as $key => $type) {
      $label_content_types[$key] = $type->label();
    }

    $bundles_counted = [];

    $language_by_default = $this->languageManager->getDefaultLanguage()->getId();
    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();

    $publish_bundle = $query->accessCheck(FALSE)
      ->condition('status', '1')
      ->groupBy('type')
      ->aggregate('nid', 'count', $language_by_default, $alias_count)
      ->execute();
    foreach ($publish_bundle as $bundle) {
      $bundles_counted[$bundle['type']]['publish'] = $bundle['count'];
    }

    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $unpublish_bundle = $query->accessCheck(FALSE)
      ->condition('status', '1', '!=')
      ->groupBy('type')
      ->aggregate('nid', 'count', $language_by_default, $alias_count)
      ->execute();
    foreach ($unpublish_bundle as $bundle) {
      $bundles_counted[$bundle['type']]['unpublish'] = $bundle['count'];
    }

    $total = 0;
    $total_publish = 0;
    $total_no_publish = 0;
    foreach ($label_content_types as $bundle => $conent_type_label) {
      $publish = $bundles_counted[$bundle]['publish'] ?? 0;
      $unpublish = $bundles_counted[$bundle]['unpublish'] ?? 0;
      $resultTable[$bundle] = [
        'label' => $conent_type_label,
        'id' => $bundle,
        'langcode' => $language_by_default,
        'total' => $publish + $unpublish,
        'publish' => $publish,
        'no_publish' => $unpublish,
      ];
      $total += $publish + $unpublish;
      $total_publish += $publish;
      $total_no_publish += $unpublish;
    }
    $resultTable['total']['label'] = $this->t('TOTAL');
    $resultTable['total']['id'] = '---';
    $resultTable['total']['langcode'] = '---';
    $resultTable['total']['total'] = $total;
    $resultTable['total']['publish'] = $total_publish;
    $resultTable['total']['no-publish'] = $total_no_publish;

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * Get data for operation "node_by_types_language".
   *
   * @return array
   *   Render array.
   */
  protected function nodeTypesPerLanguage() {

    $alias = 'count';

    $headerTable = [
      $this->t('label'),
      $this->t('id'),
      $this->t('langcode'),
      $this->t('total'),
    ];
    $resultTable = [];

    // Get label of content types.
    $label = [];
    $types = $this->entityTypeManager->getStorage("node_type")->loadMultiple();
    foreach ($types as $key => $type) {
      $label[$key] = $type->label();
    }

    $query = $this->entityTypeManager->getStorage("node")->getAggregateQuery();
    $result = $query->accessCheck(FALSE)
      ->aggregate('nid', 'COUNT', NULL, $alias)
      ->groupBy('langcode')
      ->groupBy('type')
      ->execute();

    foreach ($result as $row) {
      $resultTable[] = [
        'label' => $label[$row['type']],
        'id' => $row['type'],
        'langcode' => $row['langcode'],
        'total' => $row['count'] ?? 0,
      ];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

}
